"use strict";
exports.__esModule = true;
var react_1 = require("react");
var resizeCanvas = function (canvas) {
    var clientWidth = canvas.clientWidth, clientHeight = canvas.clientHeight;
    var needResize = canvas.width !== clientWidth || canvas.height !== clientHeight;
    if (needResize) {
        var _a = window.devicePixelRatio, ratio = _a === void 0 ? 1 : _a;
        canvas.width = clientWidth;
        canvas.height = clientHeight;
        var context = canvas.getContext('2d');
        context.scale(ratio, ratio);
    }
    return needResize;
};
var useDrawCanvas = function (draw) {
    var canvasRef = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(function () {
        var canvas = canvasRef.current;
        var frameCount = 0;
        var animationFrameId = -1;
        var render = function () {
            resizeCanvas(canvas);
            frameCount++;
            draw === null || draw === void 0 ? void 0 : draw(canvas, frameCount);
            animationFrameId = window.requestAnimationFrame(render);
        };
        render();
        return function () {
            window.cancelAnimationFrame(animationFrameId);
        };
    }, [draw]);
    return canvasRef;
};
exports["default"] = useDrawCanvas;
//# sourceMappingURL=useDrawCanvas.js.map